<p align="center">
  <a href="https://feishu.adapters.nonebot.dev/"><img src="https://feishu.adapters.nonebot.dev/logo.png" width="200" height="200" alt="nonebot"></a>
</p>

<div align="center">

# NoneBot-Adapter-Feishu

_✨ 飞书协议适配 ✨_

</div>
